@@ -72,7 +72,7 @@ for dir in dev proc sys; do
   umount "${INSTALLROOT}/${dir}"
 done
 
-rm -rfv "${INSTALLROOT}//var/cache/zypp/packages/"*
+rm -rfv "${INSTALLROOT}/var/cache/zypp/packages/"*
 
 FILE="${IMAGE//\//_}.tar"
 tar -C "${INSTALLROOT}" -c . >"${FILE}"
